@@ -1,5 +1,5 @@
 char *rcsid_common_commands_c =
-    "$Id: commands.c,v 1.22 2004/01/30 18:43:34 tchize Exp $";
+    "$Id: commands.c,v 1.30 2005/07/18 20:08:41 akirschbaum Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -215,7 +215,7 @@ void SetupCmd(char *buf, int len)
 		 * not the same size, so whats the problem?  Tell the user that
 		 * something is wrong.
 		 */
-		sprintf(tmpbuf,"Unable to set mapsize on server - we wanted %d x %d, server returnd %d x %d",
+		sprintf(tmpbuf,"Unable to set mapsize on server - we wanted %d x %d, server returned %d x %d",
 			use_config[CONFIG_MAPWIDTH], use_config[CONFIG_MAPHEIGHT], x, y);
 		draw_info(tmpbuf,NDI_RED);
 	    }
@@ -308,6 +308,20 @@ void SetupCmd(char *buf, int len)
                 cs_print_string(csocket.fd,"toggleextendedinfos smooth");
             }    
         }
+    }
+    else if (!strcmp(cmd,"extendedTextInfos")){
+        if (strcmp(param,"FALSE")){ /* server didn't send FALSE*/
+            /* Server seems to accept extended text infos. Let's tell
+             * it what extended text info we want
+             */
+            char exttext[MAX_BUF];
+            TextManager* manager = firstTextManager;
+            while (manager){
+                snprintf(exttext,sizeof(exttext),"toggleextendedtext %d",manager->type);
+                cs_print_string(csocket.fd,exttext);
+                manager=manager->next;
+            }
+        }
     }
 	else {
 		LOG (LOG_INFO,"common::SetupCmd","Got setup for a command we don't understand: %s %s",
@@ -390,56 +404,25 @@ void AnimCmd(unsigned char *data, int len)
     LOG(LOG_DEBUG,"common::AnimCmd","Received animation %d, %d faces", anum, animations[anum].num_animations);
 }
 
-Smooths smooths[MAXSMOOTH];
-int smoothused=0;
+
+/* This receives the smooth mapping from the server.  Because this
+ * information is reference a lot, the smoothing face is stored
+ * in the pixmap data - this makes access much faster than searching
+ * an array of data for the face to use.
+ */
+
 void SmoothCmd(unsigned char *data, int len){
     uint16 faceid;
     uint16 smoothing;
-    static int dx[8]={0,1,1,1,0,-1,-1,-1};
-    static int dy[8]={-1,-1,0,1,1,1,0,-1};  
-    int i,j,x,y,layer;
-    int mx,my;
 
     /* len is unused.
      * We should check that we don't have an invalid short command.
      * Hence, the compiler warning is valid.
      */
-    display_map_startupdate();
-    if (smoothused>=MAXSMOOTH) /*no place to put*/
-        return;
+
     faceid=GetShort_String(data);
     smoothing=GetShort_String(data+2);
-    for (i=0;i<smoothused;i++){
-        if (smooths[i].smoothid==faceid)
-            break;
-    }
-    if (i==smoothused)
-        smoothused++;
-    smooths[i].smoothid=faceid;
-    smooths[i].received=1;
-    smooths[i].face=smoothing;    
-    /*update the map where needed*/
-    for( x= 0; x<use_config[CONFIG_MAPWIDTH]; x++) {
-    for( y= 0; y<use_config[CONFIG_MAPHEIGHT]; y++){
-    for (layer=0;layer<MAXLAYERS;layer++){
-        mx = x + pl_pos.x;
-	    my = y + pl_pos.y;
-        if ( (the_map.cells[mx][my].smooth[layer]==0) ||
-             (the_map.cells[mx][my].heads[layer].face!=smooths[i].smoothid))
-            continue; /*not concerned*/
-        for (j=0;j<8;j++){
-            mx=x + pl_pos.x+dx[j];
-            my=y + pl_pos.y+dy[j];
-            if ( (mx<0) || (my<0) || (the_map.x<=mx) || (the_map.y<=my))
-                continue;
-            if (!the_map.cells[mx][my].cleared)
-                the_map.cells[mx][my].need_resmooth=1;
-        }
-    }
-    }
-    }
-    display_map_doneupdate(FALSE);
-    /*Should find some way to draw here, i suppose*/
+    addsmooth(faceid, smoothing);
 }
 
 void DrawInfoCmd(char *data, int len)
@@ -460,7 +443,75 @@ void DrawInfoCmd(char *data, int len)
 	draw_info(buf,NDI_BLACK);
 
 }
+TextManager* firstTextManager = NULL;
 
+void setTextManager(int type, ExtTextManager callback){
+    TextManager* current = firstTextManager;
+    while (current!=NULL){
+        if (current->type == type){            
+            current->callback=callback;
+            return;
+        }
+        current = current -> next;
+    }
+    current = malloc(sizeof(TextManager));
+    current->type = type;
+    current->callback=callback;
+    current->next = firstTextManager;
+    firstTextManager=current;
+}
+ExtTextManager getTextManager(int type){
+    TextManager* current = firstTextManager;
+    while (current!=NULL){
+        if (current->type == type){            
+            return current->callback;
+        }
+        current = current -> next;
+    }
+    return NULL;
+}
+/* We must extract color, type, subtype and dispatch to callback*/
+void DrawExtInfoCmd(char *data, int len)
+{
+    int color;
+    int type, subtype;
+    char *buf=data;
+    int wordCount=3;
+    ExtTextManager fnct;
+    while(wordCount>0){
+    	while (buf[0]==' ')
+            buf++;
+        wordCount--;
+        while(buf[0]!=' ')
+            if (buf[0]=='\0'){
+                LOG(LOG_WARNING,
+                    "common::DrawExtInfoCmd","Data is missing %d parameters %s",
+                    wordCount,
+                    data
+                );
+                return;
+            } else
+                buf++;
+        if (buf[0]==' ')
+            buf++; /*remove trailing space to send clean data to callback */
+    }
+    wordCount = sscanf(data,"%d %d %d",&color, &type, &subtype);
+    if (wordCount!=3){
+        LOG(LOG_WARNING,
+            "common::DrawExtInfoCmd","Wrong parameters received. Could only parse %d out of 3 int in %s",
+            wordCount,
+            data);
+        return;
+    }
+    fnct = getTextManager(type);
+    if (fnct == NULL){
+        LOG(LOG_WARNING,
+            "common::DrawExtInfoCmd","Server send us a type %d but i can't find any callback for it",
+            type);
+        return;
+    }
+    fnct(color,type,subtype,buf);
+}
 void StatsCmd(unsigned char *data, int len)
 {
     int i=0, c, redraw=0;
@@ -513,7 +564,7 @@ void StatsCmd(unsigned char *data, int len)
 		case CS_STAT_FOOD:	cpl.stats.food=GetShort_String(data+i); i+=2; break;
 		case CS_STAT_WEAP_SP:	cpl.stats.weapon_sp=GetInt_String(data+i); i+=4; break;
 		case CS_STAT_FLAGS:	cpl.stats.flags=GetShort_String(data+i); i+=2; break;
-		case CS_STAT_WEIGHT_LIM:set_weight_limit(GetInt_String(data+i)); i+=4; break;
+		case CS_STAT_WEIGHT_LIM:set_weight_limit(cpl.stats.weight_limit=GetInt_String(data+i)); i+=4; break;
 
 		/* Skill experience handling */
 		/* We make the assumption based on current bindings in the protocol
@@ -586,8 +637,6 @@ void handle_query (char *data, int len)
 	    draw_info(cp, NDI_BLACK);
 	    cp = buf;
 	}
-	if (cp) draw_prompt(cp);
-    }
     /* Yes/no - don't do anything with it now */
     if (flags & CS_QUERY_YESNO) {}
 
@@ -597,6 +646,8 @@ void handle_query (char *data, int len)
     else
 	cpl.input_state = Reply_Many;
 
+    if (cp) draw_prompt(cp);
+    }
     if (flags & CS_QUERY_HIDEINPUT)		/* no echo */
 	cpl.no_echo=1;
     else
@@ -613,7 +664,7 @@ void handle_query (char *data, int len)
  * the stuff up.
  */
 
-void send_reply(char *text)
+void send_reply(const char *text)
 {
     cs_print_string(csocket.fd, "reply %s", text);
 }
@@ -1316,3 +1367,6 @@ void MagicMapCmd(unsigned char *data, int len)
     cpl.showmagic=1;
     draw_magic_map();
 }
+
+void SinkCmd(unsigned char *data, int len){
+}
