@@ -1,5 +1,5 @@
 char *rcsid_common_image_c =
-    "$Id: image.c,v 1.16 2004/01/30 22:03:37 ryo_saeba Exp $";
+    "$Id: image.c,v 1.18 2005/03/27 20:51:24 akirschbaum Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -171,7 +171,7 @@ char	home_dir[MAX_BUF];
 /* This holds the name we recieve with the 'face' command so we know what
  * to save it as when we actually get the face.
  */
-char *facetoname[MAXPIXMAPNUM];
+static char *facetoname[MAXPIXMAPNUM];
 
 
 struct Image_Cache {
@@ -335,6 +335,12 @@ void init_common_cache_data()
     char    bmaps[MAX_BUF], inbuf[MAX_BUF];
     int i;
 
+    if (!want_config[CONFIG_CACHE])
+	return;
+
+    for (i = 0; i < MAXPIXMAPNUM; i++)
+	facetoname[i] = NULL;
+
     /* First, make sure that image_cache is nulled out */
     memset(image_cache, 0, IMAGE_HASH * sizeof(struct Image_Cache));
 
@@ -367,33 +373,6 @@ void init_common_cache_data()
 void requestsmooth (int pnum){
     cs_print_string (csocket.fd, "asksmooth %d",pnum);
 }
-int getsmooth (int face){
-    int i;
-    if (smoothused<1){
-        smooths[0].smoothid=face;
-        smooths[0].received=0;
-        requestsmooth(face);
-        smoothused++;
-        return 0;
-    }
-    for (i=0;i<smoothused;i++){
-        if (smooths[i].smoothid==face){
-            if (smooths[i].received)
-                return smooths[i].face;
-            else{
-                return -1;
-            }
-        }
-    }
-    if (smoothused<MAXSMOOTH){
-        smooths[smoothused].smoothid=face;
-        smooths[smoothused].received=0;
-        requestsmooth(face);
-        smoothused++;
-        return -1;
-    }
-    return -1;
-}
 
 /******************************************************************************
  *
@@ -506,11 +485,6 @@ void reset_image_cache_data()
 	    facetoname[i]=NULL;
 	}
     }
-    /* Also reset smooth data, considered to be part of image cache
-     * (Actually this is the better place to handle it) :P
-     */
-    smoothused=0;
-    memset (smooths,sizeof(Smooths)*MAXSMOOTH,0);
 }
 
 
@@ -716,7 +690,9 @@ void display_newpng(long face,uint8 *buf,long buflen, int setnum)
     }
 
     pngtmp = png_to_data(buf, buflen, &width, &height);
-    create_and_rescale_image_from_data(ce, face, pngtmp, width, height);
+    if(create_and_rescale_image_from_data(ce, face, pngtmp, width, height)) {
+	LOG(LOG_WARNING, "common::display_newpng", "create_and_rescale_image_from_data failed for face %ld", face);
+    }
 
     if (use_config[CONFIG_CACHE]) {
 	if (facetoname[face]) {
