@@ -1,5 +1,5 @@
 char *rcsid_common_misc_c =
-    "$Id: misc.c,v 1.8 2004/01/30 18:43:34 tchize Exp $";
+    "$Id: misc.c,v 1.10 2005/03/28 06:44:53 mwedel Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -24,7 +24,7 @@ char *rcsid_common_misc_c =
 
 /*
  * static char *rcsid_misc_c =
- *   "$Id: misc.c,v 1.8 2004/01/30 18:43:34 tchize Exp $";
+ *   "$Id: misc.c,v 1.10 2005/03/28 06:44:53 mwedel Exp $";
  */
 
 
@@ -121,7 +121,7 @@ int make_path_to_file (char *filename)
  * unix variants.
  */
 
-char *strdup_local(char *str) {
+char *strdup_local(const char *str) {
   char *c=(char *)malloc(sizeof(char)*strlen(str)+1);
   strcpy(c,str);
   return c;
@@ -241,9 +241,10 @@ void monitorChilds(){
         if (!cp)
             return; /*no child to monitor*/
         if (waitpid(cp->pid,NULL,WNOHANG)){
+            ChildProcess* next;
+
             /*pid is dead*/
             LOG(LOG_INFO,"common::monitorChilds","Child %s died. Removing and closing pipes",cp->name?cp->name:"UNKNOWN");
-            ChildProcess* next;
             if (cp==LastChild)
                 LastChild=last;
             next=cp->next;
