@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_newclient_h =
- *   "$Id: newclient.h,v 1.4 2003/06/19 12:23:39 tchize Exp $";
+ *   "$Id: newclient.h,v 1.6 2005/05/29 15:34:44 tchize Exp $";
  */
 
 /*
@@ -268,4 +268,89 @@ extern CS_Stats cst_tot, cst_lst;
  */
 #define EMI_HASMOREBITS     0x80
 
+
+/* used by ext text */
+/* message types */
+#define MSG_TYPE_BOOK            1
+#define MSG_TYPE_CARD            2
+#define MSG_TYPE_PAPER           3
+#define MSG_TYPE_SIGN            4
+#define MSG_TYPE_MONUMENT        5
+#define MSG_TYPE_SCRIPTED_DIALOG 6
+#define MSG_TYPE_MOTD            7
+#define MSG_TYPE_ADMIN           8
+
+
+
+/* book messages subtypes */
+#define MSG_TYPE_BOOK_CLASP_1    1
+#define MSG_TYPE_BOOK_CLASP_2    2
+#define MSG_TYPE_BOOK_ELEGANT_1  3
+#define MSG_TYPE_BOOK_ELEGANT_2  4
+#define MSG_TYPE_BOOK_QUARTO_1   5
+#define MSG_TYPE_BOOK_QUARTO_2   6
+#define MSG_TYPE_BOOK_SPELL_EVOKER    8
+#define MSG_TYPE_BOOK_SPELL_PRAYER    9
+#define MSG_TYPE_BOOK_SPELL_PYRO      10
+#define MSG_TYPE_BOOK_SPELL_SORCERER  11
+#define MSG_TYPE_BOOK_SPELL_SUMMONER  12
+
+/* card messages subtypes*/
+#define MSG_TYPE_CARD_SIMPLE_1    1
+#define MSG_TYPE_CARD_SIMPLE_2    2
+#define MSG_TYPE_CARD_SIMPLE_3    3
+#define MSG_TYPE_CARD_ELEGANT_1   4
+#define MSG_TYPE_CARD_ELEGANT_2   5
+#define MSG_TYPE_CARD_ELEGANT_3   6
+#define MSG_TYPE_CARD_STRANGE_1   7
+#define MSG_TYPE_CARD_STRANGE_2   8
+#define MSG_TYPE_CARD_STRANGE_3   9
+#define MSG_TYPE_CARD_MONEY_1     10
+#define MSG_TYPE_CARD_MONEY_2     11
+#define MSG_TYPE_CARD_MONEY_3     12
+
+/* Paper messages subtypes */
+#define MSG_TYPE_PAPER_NOTE_1       1
+#define MSG_TYPE_PAPER_NOTE_2       2
+#define MSG_TYPE_PAPER_NOTE_3       3
+#define MSG_TYPE_PAPER_LETTER_OLD_1 4
+#define MSG_TYPE_PAPER_LETTER_OLD_2 5
+#define MSG_TYPE_PAPER_LETTER_NEW_1 6
+#define MSG_TYPE_PAPER_LETTER_NEW_2 7
+#define MSG_TYPE_PAPER_ENVELOPE_1   8
+#define MSG_TYPE_PAPER_ENVELOPE_2   9
+#define MSG_TYPE_PAPER_SCROLL_OLD_1 10
+#define MSG_TYPE_PAPER_SCROLL_OLD_2 11
+#define MSG_TYPE_PAPER_SCROLL_NEW_1 12
+#define MSG_TYPE_PAPER_SCROLL_NEW_2 13
+#define MSG_TYPE_PAPER_SCROLL_MAGIC 14
+
+/* road signs messages subtypes */
+#define MSG_TYPE_SIGN_BASIC         1
+#define MSG_TYPE_SIGN_DIR_LEFT      2
+#define MSG_TYPE_SIGN_DIR_RIGHT     3
+#define MSG_TYPE_SIGN_DIR_BOTH      4
+
+/* stones and monument messages */
+#define MSG_TYPE_MONUMENT_STONE_1      1
+#define MSG_TYPE_MONUMENT_STONE_2      2
+#define MSG_TYPE_MONUMENT_STONE_3      3
+#define MSG_TYPE_MONUMENT_STATUE_1     4
+#define MSG_TYPE_MONUMENT_STATUE_2     5
+#define MSG_TYPE_MONUMENT_STATUE_3     6
+#define MSG_TYPE_MONUMENT_GRAVESTONE_1 7
+#define MSG_TYPE_MONUMENT_GRAVESTONE_2 8
+#define MSG_TYPE_MONUMENT_GRAVESTONE_3 9
+#define MSG_TYPE_MONUMENT_WALL_1       10
+#define MSG_TYPE_MONUMENT_WALL_2       11
+#define MSG_TYPE_MONUMENT_WALL_3       12
+
+/* dialog messsage */
+#define MSG_TYPE_DIALOG_NPC            1 /*A message from the npc*/
+#define MSG_TYPE_DIALOG_ANSWER         2 /*One of possible answers*/
+#define MSG_TYPE_DIALOG_ANSWER_COUNT   3 /*Number of possible answers*/
+
+/* admin messages */
+#define MSG_TYPE_ADMIN_RULES           1
+#define MSG_TYPE_ADMIN_NEWS            2
 #endif
