@@ -1,5 +1,5 @@
 char *rcsid_common_script_c =
-    "$Id: script.c,v 1.6 2004/04/04 10:07:46 ryo_saeba Exp $";
+    "$Id: script.c,v 1.13 2005/07/18 20:10:17 akirschbaum Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -23,6 +23,12 @@ char *rcsid_common_script_c =
     The author can be reached via e-mail to crossfire-devel@real-time.com
 */
 
+/* This file has its own script.h for prototypes, so don't want to include
+ * this when doing a 'make proto'
+ */
+#ifndef CPROTO
+
+
 /*
  * This file handles the client-side scripting interface.
  *
@@ -114,11 +120,13 @@ Someday this will be fixed :)
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/wait.h>
+#include <signal.h>
 #endif
 
 #include <client.h>
 #include <external.h>
 #include <script.h>
+#include <p_cmd.h>
 
 /*
  * Data structures
@@ -155,7 +163,7 @@ static int num_scripts = 0;
 /*
  * Prototypes
  */
-static int script_by_name(char *name);
+static int script_by_name(const char *name);
 static void script_dead(int i);
 static void script_process_cmd(int i);
 static void send_map(int i,int x,int y);
@@ -184,7 +192,7 @@ static int emulate_read(HANDLE fd, char *buf, int len)
    return(dwBytesRead);
 }
 
-static int emulate_write(HANDLE fd, char *buf, int len)
+static int emulate_write(HANDLE fd, const char *buf, int len)
 {
    DWORD dwBytesWritten;
    BOOL	rc;
@@ -199,7 +207,7 @@ static int emulate_write(HANDLE fd, char *buf, int len)
 
 #endif /* WIN32 */
 
-void script_init(char *params)
+void script_init(const char *cparams)
 {
 #ifndef WIN32
    int pipe1[2];
@@ -207,7 +215,20 @@ void script_init(char *params)
    int pipe2[2];
 #endif
    int pid;
-   char *name,*args;
+   char *name, *args, params[MAX_BUF];
+
+   if ( !cparams )
+       {
+       draw_info( "Please specifiy a script to launch!", NDI_RED );
+       return;
+       }
+
+    /* cparams as passed in is a const value, so need to copy it
+     * to data we can write over.
+     */
+    strncpy(params, cparams, MAX_BUF-1);
+    params[MAX_BUF-1]=0;
+    
 
    /* Get name and args */
    name=params;
@@ -218,10 +239,12 @@ void script_init(char *params)
    {
       args=NULL;
    }
+#if 0
    else
    {
       args[-1]=0;
    }
+#endif
 
 #ifdef USE_PIPE
    /* Create two pipes */
@@ -300,8 +323,22 @@ void script_init(char *params)
       for (i=3;i<100;++i) close(i);
 
       /* EXEC */
-      execvp(argv[0],argv);
-      exit(1); /* Should not be reached */
+      r = execvp(argv[0],argv);
+
+      /* If we get here, then there's been an failure of some sort.
+       * In my case, it's often that I don't know what script name to
+       * give to /script, so exec() can't find the script.
+       *
+       * Forward the error back to the client, using the script pipes. 
+       */
+
+      if (r != -1) {
+          printf("draw %d Script child: no error, but no execvp().\n", NDI_RED);
+      } else {
+          printf("draw %d Script child failed to start: %s\n", NDI_RED, strerror(errno));
+      }
+
+      exit(1);
    }
 
    /* Close the child's pipe ends */
@@ -335,12 +372,22 @@ void script_init(char *params)
 #else /* WIN32 */
 
    char *name,*args;
+   char params[ MAX_BUF ];
    SECURITY_ATTRIBUTES saAttr;
    PROCESS_INFORMATION piProcInfo;
    STARTUPINFO siStartupInfo;
    HANDLE hChildStdinRd, hChildStdinWr, hChildStdinWrDup, hChildStdoutRd;
    HANDLE hChildStdoutWr, hChildStdoutRdDup, hSaveStdin, hSaveStdout;
 
+   if ( !cparams )
+        {
+        draw_info( "Please specifiy a script to launch!", NDI_RED );
+        return;
+        }
+
+   strncpy(params, cparams, MAX_BUF-1);
+   params[MAX_BUF-1] = '\0';
+
    /* Get name and args */
    name=params;
    args=name;
@@ -491,7 +538,7 @@ void script_list(void)
    }
 }
 
-void script_kill(char *params)
+void script_kill(const char *params)
 {
    int i;
 
@@ -507,6 +554,7 @@ void script_kill(char *params)
 #else
     GenerateConsoleCtrlEvent(CTRL_BREAK_EVENT, scripts[i].pid);
 #endif /* WIN32 */
+   draw_info( "Killed script.", NDI_RED );
    script_dead(i);
 }
 
@@ -848,7 +896,7 @@ void script_monitor_str(const char *command)
    }
 }
 
-void script_tell(char *params)
+void script_tell(const char *params)
 {
    int i;
 
@@ -866,7 +914,7 @@ void script_tell(char *params)
    write(scripts[i].out_fd,"\r\n",2);
 }
 
-static int script_by_name(char *name)
+static int script_by_name(const char *name)
 {
    int i;
    int l;
@@ -991,6 +1039,7 @@ static void script_process_cmd(int i)
     * unwatch <command type>
     * request <data type>
     * issue <repeat> <must_send> <command>
+    * localcmd <command> [<params>]
     * draw <color> <text>
     * monitor
     * unmonitor
@@ -1067,14 +1116,12 @@ static void script_process_cmd(int i)
          sprintf(buf,"request range %s\n",cpl.range);
          write(scripts[i].out_fd,buf,strlen(buf));
       }
-#if 0
       else if ( strncmp(c,"weight",5)==0 ) {
          char buf[1024];
 
-         sprintf(buf,"request weight %d %d\n",inv_list.weight_limit,inv_list.show_weight);
+         sprintf(buf,"request weight %d %d\n",cpl.stats.weight_limit,(int)(cpl.ob->weight*1000));
          write(scripts[i].out_fd,buf,strlen(buf));
       }
-#endif
       else if ( strncmp(c,"stat ",5)==0 ) {
          c+=4;
          while ( *c && *c!=' ' ) ++c;
@@ -1172,7 +1219,7 @@ static void script_process_cmd(int i)
          if ( strncmp(c,"on",2)==0 ) {
             char *buf;
 
-            item *it=cpl.below;
+            item *it=cpl.below->inv;
             while (it) {
                script_send_item(i,"request items on ",it);
                it=it->next;
@@ -1183,7 +1230,7 @@ static void script_process_cmd(int i)
          if ( strncmp(c,"cont",4)==0 ) {
             char *buf;
 
-            item *it=cpl.container;
+            item *it=cpl.container->inv;
             while (it) {
                script_send_item(i,"request items cont ",it);
                it=it->next;
@@ -1242,7 +1289,7 @@ static void script_process_cmd(int i)
       else {
          char buf[1024];
 
-         sprintf(buf,"Script %d %s malfunction; unimplemented request:",i,scripts[i].name);
+         sprintf(buf,"Script %d %s malfunction; unimplemented request:",i+1,scripts[i].name);
          draw_info(buf,NDI_RED);
          draw_info(cmd,NDI_RED);
       }
@@ -1270,7 +1317,7 @@ static void script_process_cmd(int i)
             if ( r!=1 ) {
                char buf[1024];
 
-               sprintf(buf,"Script %d %s malfunction; command not sent",i,scripts[i].name);
+               sprintf(buf,"Script %d %s malfunction; command not sent",i+1,scripts[i].name);
                draw_info(buf,NDI_RED);
                draw_info(cmd,NDI_RED);
             }
@@ -1327,6 +1374,25 @@ static void script_process_cmd(int i)
          }
       }
    }
+   else if ( strncmp(cmd,"localcmd",8)==0){
+      char* param;
+      c=cmd+8;
+      while (*c==' ') c++;
+      param=c;
+      while ( (*param!='\0') && (*param!=' ')) param++;
+      if (*param==' '){
+         *param='\0';
+         *param++;
+      } else
+         param=NULL;
+      if (!handle_local_command(c, param)){
+         char buf[1024];
+         sprintf(buf,"Script %s malfunction; localcmd not understood",scripts[i].name);
+         draw_info(buf,NDI_RED);
+         sprintf(buf,"Script <<localcmd %s %s>>",c,(param==NULL)?"":param);
+         draw_info(buf,NDI_RED);
+      }
+   }
    else if ( strncmp(cmd,"draw",4)==0 ) {
       int color;
 
@@ -1344,7 +1410,7 @@ static void script_process_cmd(int i)
    else {
       char buf[1024];
 
-      sprintf(buf,"Script %d %s malfunction; invalid command:",i,scripts[i].name);
+      sprintf(buf,"Script %d %s malfunction; invalid command:",i+1,scripts[i].name);
       draw_info(buf,NDI_RED);
       draw_info(cmd,NDI_RED);
    }
@@ -1380,3 +1446,5 @@ static void script_send_item(int i,char *head,item *it)
    sprintf(buf,"%s%d %d %f %d %d %s\n",head,it->tag,it->nrof,it->weight,flags,it->type,it->d_name);
    write(scripts[i].out_fd,buf,strlen(buf));
 }
+
+#endif /* CPROTO */
