@@ -1,5 +1,5 @@
 char *rcsid_gtk_config_c =
-    "$Id: config.c,v 1.18 2004/01/30 18:43:34 tchize Exp $";
+    "$Id: config.c,v 1.21 2005/05/30 21:01:57 ryo_saeba Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -188,7 +188,7 @@ CButtons cbuttons[MAX_BUTTONS] = {
     "Map Scale (Takes effect next run)"},
 {NULL, 	    CBUTTON,	    CONFIG_SMOOTH,	FLAG_MAPPANE | FLAG_UPDATE,
     "Enable smoothing - Use additionnal CPU (Take effect on next connection)."},
-{NULL, 	    CBUTTON,	    CONFIG_SDL,		FLAG_MAPPANE,
+{NULL, 	    CBUTTON,	    CONFIG_DISPLAYMODE,	FLAG_MAPPANE,
     "SDL Image Support (Take effect next run)"},
 {NULL, 	    CBUTTON,	    CONFIG_SHOWGRID,	FLAG_MAPPANE | FLAG_UPDATE,
     "Print Grid Overlay (SDL only, Slow, useful for debugging/development"},
@@ -223,28 +223,25 @@ static void set_config_value(int cval, int value)
 
 static void toggle_splitwin(int newval)
 {
-    /* Currently don't have it, but want splitwindows */
+    inventory_splitwin_toggling();
+	gtk_widget_destroy(gtkwin_root);
+        
     if (newval) {
-	gtk_widget_destroy(gtkwin_root);
-	create_windows();
-	display_map_doneupdate(TRUE);
-	draw_stats (1);
-	draw_all_list(&inv_list);
-	draw_all_list(&look_list);
-    }
-    else { /* opposite - do have it, but don't want it */
-	gtk_widget_destroy(gtkwin_root);
+        ; /* Currently don't have it, but want splitwindows */
+    } else { 
+        /* opposite - do have it, but don't want it */
 	gtk_widget_destroy(gtkwin_info);
 	gtk_widget_destroy(gtkwin_stats);
 	gtk_widget_destroy(gtkwin_message);
 	gtk_widget_destroy(gtkwin_inv);
 	gtk_widget_destroy(gtkwin_look);
+    }
+
 	create_windows();
 	display_map_doneupdate(TRUE);
 	draw_stats (1);
-	draw_all_list(&inv_list);
-	draw_all_list(&look_list);
-    }
+    update_list_labels(&inv_list); /* After exploding or unexploding client, redraw weight labels. */
+    update_list_labels(&look_list);
 }
 
 /* Ok, here it sets the config and saves it. This is sorta dangerous, and I'm not sure
@@ -305,9 +302,8 @@ void applyconfig () {
 	use_config[CONFIG_SOUND] = want_config[CONFIG_SOUND];
     }
     if (IS_DIFFERENT(CONFIG_COLORINV)) {
-	draw_all_list(&inv_list);
-	draw_all_list(&look_list);
 	use_config[CONFIG_COLORINV] = want_config[CONFIG_COLORINV];
+	inventory_update_colorinv();
     }
     if (IS_DIFFERENT(CONFIG_TOOLTIPS)) {
 	if (want_config[CONFIG_TOOLTIPS]) gtk_tooltips_enable(tooltips);
@@ -331,8 +327,8 @@ void applyconfig () {
 	use_config[CONFIG_FASTTCP] = want_config[CONFIG_FASTTCP];
     }
     if (IS_DIFFERENT(CONFIG_SHOWICON)) {
-	inv_list.show_icon = want_config[CONFIG_SHOWICON];
-	draw_all_list(&inv_list);
+	itemlist_set_show_icon(&inv_list, want_config[CONFIG_SHOWICON]);
+	/* TODO What about the look list? And should showicon propogate back here? */
 	use_config[CONFIG_SHOWICON] = want_config[CONFIG_SHOWICON];
     }
     if (IS_DIFFERENT(CONFIG_RESISTS)) {    
@@ -348,7 +344,7 @@ void applyconfig () {
 	    use_config[CONFIG_LIGHTING] = lighting;
 	}
 #ifdef HAVE_SDL
-	if (use_config[CONFIG_SDL])
+	if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL)
 	    /* This is done to make the 'lightmap' in the proper format */
 	    init_SDL( NULL, 1);
 #endif
@@ -769,6 +765,10 @@ void load_defaults()
 	    server = strdup_local(cp);	/* memory leak ! */
 	    continue;
 	}
+	else if (!strcmp(inbuf, "sound_server")) {
+	    sound_server = strdup_local(cp);	/* memory leak ! */
+	    continue;
+	}
 	else if (!strcmp(inbuf, "nopopups")) {
 	    /* Changed name from nopopups to popups, so inverse value */
 	    want_config[CONFIG_POPUPS] = !val;
@@ -848,7 +848,7 @@ void load_defaults()
     image_size = DEFAULT_IMAGE_SIZE * use_config[CONFIG_ICONSCALE] / 100;
     map_image_size = DEFAULT_IMAGE_SIZE * use_config[CONFIG_MAPSCALE] / 100;
     map_image_half_size = DEFAULT_IMAGE_SIZE * use_config[CONFIG_MAPSCALE] / 200;
-    inv_list.show_icon = use_config[CONFIG_SHOWICON];
+    itemlist_set_show_icon(&inv_list, use_config[CONFIG_SHOWICON]); 
 
 }
 
@@ -873,6 +873,7 @@ void save_defaults()
     fprintf(fp,"# 'True' and 'False' are the proper cases for those two values\n");
     fprintf(fp,"# 'True' and 'False' have been replaced with 1 and 0 respectively\n");
     fprintf(fp,"server: %s\n", server);
+    fprintf(fp,"sound_server: %s\n", sound_server);
     fprintf(fp,"faceset: %s\n", face_info.want_faceset);
 
     /* This isn't quite as good as before, as instead of saving things as 'True'
