@@ -1,5 +1,5 @@
 char *rcsid_gtk_keys_c =
-    "$Id: keys.c,v 1.15 2004/03/04 22:31:25 ryo_saeba Exp $";
+    "$Id: keys.c,v 1.19 2005/07/30 19:31:44 ryo_saeba Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -51,6 +51,7 @@ typedef int KeyCode; /* Undefined type */
 #include "client-types.h"
 #include "gx11.h"
 #include "client.h"
+#include "p_cmd.h"
 
 #include "def-keys.h"
 
@@ -110,7 +111,7 @@ static Key_Entry *keys[KEYHASH];
  * that the keyboard is in.
  * This function is common to both gdk and x11 client
  */
-static void insert_key(uint32 keysym, int flags, char *command)
+static void insert_key(uint32 keysym, int flags, const char *command)
 {
 
     Key_Entry *newkey;
@@ -472,6 +473,9 @@ static void parse_key(char key, uint32 keysym)
 	    cpl.input_state = Command_Mode;
    	    gtk_entry_set_text(GTK_ENTRY(entrytext),cpl.input_text);
 	    gtk_widget_grab_focus (GTK_WIDGET(entrytext));
+#ifdef WIN32
+        gtk_editable_select_region(GTK_EDITABLE(entrytext),strlen(cpl.input_text),-1);
+#endif
 	    return;
 	}
 
@@ -579,7 +583,7 @@ static void show_keys(int allbindings)
 {
     int i, count=1;
     Key_Entry *key;
-    char buf[MAX_BUF];
+    char buf[MAX_BUF + sizeof( bind_buf )];
 
   sprintf(buf, "Commandkey %s", 
 	  commandkeysym==NoSymbol?"unknown":gdk_keyval_name(commandkeysym));
@@ -624,9 +628,10 @@ static void show_keys(int allbindings)
 
 
 
-void bind_key(char *params)
+void bind_key(const char *params)
 {
-    char buf[MAX_BUF + 16];
+    /* Must have enough room for MAX_BUF and 'Push key to bind to ''.' */
+    char buf[MAX_BUF + 20];
 
     if (!params) {
 	draw_info("Usage: bind [-nfre] {<commandline>/commandkey/firekey{1/2}/runkey{1/2}/",NDI_BLACK);
@@ -730,15 +735,20 @@ void bind_key(char *params)
 	return;
     }
 
+    /* params is read only, so we need to the truncation on
+     * the buffer we will store it in, not params
+     */
+    strncpy(bind_buf, params, sizeof(bind_buf)-1);
+    bind_buf[sizeof(bind_buf)-1] = 0;
+
     if (strlen(params) >= sizeof(bind_buf)) {
-	params[sizeof(bind_buf) - 1] = '\0';
-    draw_info("Keybinding too long! Truncated:",NDI_RED);
-    draw_info(params,NDI_RED);
+	draw_info("Keybinding too long! Truncated:",NDI_RED);
+	draw_info(bind_buf,NDI_RED);
     }
-    sprintf(buf, "Push key to bind '%s'.", params);
+
+    sprintf(buf, "Push key to bind '%s'.", bind_buf);
     draw_info(buf,NDI_BLACK);
 
-    strcpy(bind_buf, params);
     cpl.input_state = Configure_Keys;
     return;
 }
@@ -888,11 +898,14 @@ static void unbind_usage()
     draw_info("    -g unbinds a global binding", NDI_BLACK);
 }
 
-void unbind_key(char *params)
+void unbind_key(const char *params)
 {
     int count=0, keyentry, onkey,global=0;
     Key_Entry *key, *tmp;
-    char buf[MAX_BUF];
+    /* the key macro itself can be bind_buf long, and we need some extra
+     * space for the sprintf unbind message.
+     */
+    char buf[sizeof(bind_buf)+60];
 
     if (params==NULL || params[0]=='\0') {
 	show_keys(0);
@@ -1134,9 +1147,9 @@ void draw_keybindings (GtkWidget *keylist) {
     
 void bind_callback (GtkWidget *gtklist, GdkEventButton *event) {
     KeySym keysym;
-    gchar *entry_text;
-    gchar *cpnext;
-    gchar *mod="";
+    const gchar *entry_text;
+    const gchar *cpnext;
+    const gchar *mod="";
     char buf[MAX_BUF];
       
     bind_flags = KEYF_MODIFIERS;
