@@ -1,5 +1,5 @@
 char *rcsid_gtk_map_c =
-    "$Id: map.c,v 1.23 2004/01/30 18:43:34 tchize Exp $";
+    "$Id: map.c,v 1.26 2005/03/23 22:18:57 tchize Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -202,7 +202,7 @@ void set_map_darkness(int x, int y, uint8 darkness)
 	 * let the neighbors know they should update their darkness
 	 * now.
 	 */
-	if (use_config[CONFIG_SDL] && 
+	if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL && 
 	    (use_config[CONFIG_LIGHTING] == CFG_LT_PIXEL ||
 	     use_config[CONFIG_LIGHTING] == CFG_LT_PIXEL_BEST)) {
 	    if (x-1>0) the_map.cells[x-1][y].need_update = 1;
@@ -369,7 +369,7 @@ void display_mapscroll(int dx,int dy)
     } /* for x */
 
 #ifdef HAVE_SDL
-    if (use_config[CONFIG_SDL])
+    if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL)
 	sdl_mapscroll(dx,dy);
     else
 #endif
@@ -431,8 +431,9 @@ void drawsmooth (int mx,int my,int layer,int picx,int picy){
     int emx,emy;
     int smoothface;
     int dosmooth=0;
+
     if ( (the_map.cells[mx][my].heads[0].face==0)
-         || !CAN_SMOOTH(the_map.cells[mx][my].smooth[layer]) )
+         || !CAN_SMOOTH(the_map.cells[mx][my],layer) )
         return;
     for (i=0;i<8;i++){
         emx=mx+dx[i];
@@ -446,7 +447,7 @@ void drawsmooth (int mx,int my,int layer,int picx,int picy){
             sfaces[i]=0; /*black picture*/
         }else{      
             slevels[i]=the_map.cells[emx][emy].smooth[layer];
-            sfaces[i]=getsmooth(the_map.cells[emx][emy].heads[layer].face);
+            sfaces[i]=pixmaps[the_map.cells[emx][emy].heads[layer].face]->smooth_face;
             dosmooth=1;
         }                    
     }
@@ -527,6 +528,7 @@ void gtk_draw_map(int redraw) {
     int mx,my, layer,x,y, src_x, src_y;
     struct timeval tv1, tv2,tv3;
     long elapsed1, elapsed2;
+
     if (time_map_redraw)
 	gettimeofday(&tv1, NULL);
 
@@ -540,7 +542,8 @@ void gtk_draw_map(int redraw) {
 
 	    /* Don't need to touch this space */
 	    if (!redraw && !the_map.cells[mx][my].need_update && !map_did_scroll&& !the_map.cells[mx][my].need_resmooth)
-            continue;
+		continue;
+
 	    /* First, we need to black out this space. */
 	    gdk_draw_rectangle(mapwindow, drawingarea->style->black_gc, TRUE, x * map_image_size, y * map_image_size, map_image_size, map_image_size);
 	    /* now draw the different layers.  Only draw if using fog of war or the
@@ -581,12 +584,7 @@ void gtk_draw_map(int redraw) {
 			src_y = pixmaps[the_map.cells[mx][my].heads[layer].face]->map_height - map_image_size;
 
             
-            gdk_gc_set_clip_mask (mapgc, pixmaps[the_map.cells[mx][my].heads[layer].face]->map_mask);
-			/*GdkBitmap *newmask=NULL;
-            newmask=createpartialmask(pixmaps[the_map.cells[mx][my].heads[layer].face]->map_mask,
-                map_image_size/4,map_image_size/4,map_image_size/2,map_image_size/2,
-                map_image_size,map_image_size);
-            gdk_gc_set_clip_mask (mapgc, newmask);*/
+			gdk_gc_set_clip_mask (mapgc, pixmaps[the_map.cells[mx][my].heads[layer].face]->map_mask);
 			gdk_gc_set_clip_origin(mapgc, 
 					       (x + 1 - the_map.cells[mx][my].heads[layer].size_x) * map_image_size,
 					       (y + 1 - the_map.cells[mx][my].heads[layer].size_y) * map_image_size);
@@ -595,27 +593,26 @@ void gtk_draw_map(int redraw) {
 				    pixmaps[the_map.cells[mx][my].heads[layer].face]->map_image,
 				    src_x, src_y, x * map_image_size, y * map_image_size,
 					map_image_size, map_image_size);
-            /*We draw the pic. Now, smooth adjacent squares on it*/
-            if ( use_config[CONFIG_SMOOTH])
-                drawsmooth (mx,my,layer,x * map_image_size,y * map_image_size);
-            }
-            /*Sometimes, it may happens we need to draw the smooth while there
-              is nothing to draw at that layer (but there was something at lower
-              layers). This is handled here. The else part is to take into account
-              cases where the smooth as already been handled 2 code lines before*/
-            else if ( use_config[CONFIG_SMOOTH] &&
-                 the_map.cells[mx][my].need_resmooth )
-                drawsmooth (mx,my,layer,x * map_image_size,y * map_image_size);
+			/*We draw the pic. Now, smooth adjacent squares on it*/
+			if ( use_config[CONFIG_SMOOTH])
+			    drawsmooth (mx,my,layer,x * map_image_size,y * map_image_size);
+		    }
+		    /* Sometimes, it may happens we need to draw the smooth while there
+		     * is nothing to draw at that layer (but there was something at lower
+		     * layers). This is handled here. The else part is to take into account
+		     * cases where the smooth as already been handled 2 code lines before
+		     */
+		    else if ( use_config[CONFIG_SMOOTH] &&
+			     the_map.cells[mx][my].need_resmooth )
+			drawsmooth (mx,my,layer,x * map_image_size,y * map_image_size);
             
-            /*if (newmask)
-                gdk_pixmap_unref(newmask);*/
-
 		    
 		} /* else for processing the layers */
-        the_map.cells[mx][my].need_resmooth=0;
+	    the_map.cells[mx][my].need_resmooth=0;
 
 	    /* Do final logic for this map space */
 	    the_map.cells[mx][my].need_update=0;
+
 	    /* If this is a fog cell, do darknening of the space.
 	     * otherwise, process light/darkness - only do those if not a 
 	     * fog cell.
@@ -654,10 +651,10 @@ void gtk_draw_map(int redraw) {
 
 	} /* For y spaces */
     } /* for x spaces */
-
     if (time_map_redraw)
 	gettimeofday(&tv2, NULL);
 
+
     /* map_did_scroll is set if the map scrolls for example.  In this case, we need to redraw
      * the entire map.
      */
