@@ -1,5 +1,5 @@
 char *rcsid_gtk_png_c =
-    "$Id: png.c,v 1.9 2004/01/30 18:43:34 tchize Exp $";
+    "$Id: png.c,v 1.11 2005/05/29 16:42:19 ryo_saeba Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -68,7 +68,7 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
 
     png_structp	png_ptr;
     png_infop	info_ptr;
-    int bit_depth, color_type, interlace_type, compression_type, filter_type, y;
+    int bit_depth, color_type, interlace_type, compression_type, y;
 
     data_len=len;
     data_cp = data;
@@ -93,10 +93,23 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
 
     png_set_read_fn(png_ptr, NULL, user_read_data);
     png_read_info (png_ptr, info_ptr);
-
+    /*
+     * This seems to bug on at least one system (other than mine)
+     * http://www.metalforge.net/cfmb/viewtopic.php?t=1085
+     *
+     * I think its actually a bug in libpng. This function dies with an 
+     * error based on image width. However I've produced a work around
+     * using the indivial functions. Repeated below.
+     * 
     png_get_IHDR(png_ptr, info_ptr, (png_uint_32*)width, (png_uint_32*)height, &bit_depth,
 		 &color_type, &interlace_type, &compression_type, &filter_type);
-
+    */
+    *width = png_get_image_width(png_ptr, info_ptr);
+    *   height = png_get_image_height(png_ptr, info_ptr);
+    bit_depth = png_get_bit_depth(png_ptr, info_ptr);
+    color_type = png_get_color_type(png_ptr, info_ptr);
+    interlace_type = png_get_interlace_type(png_ptr, info_ptr);
+    compression_type = png_get_compression_type(png_ptr, info_ptr);
     if (color_type == PNG_COLOR_TYPE_PALETTE &&
             bit_depth <= 8) {
 
@@ -149,9 +162,18 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
     /* Update the info the reflect our transformations */
     png_read_update_info(png_ptr, info_ptr);
     /* re-read due to transformations just made */
+    /*
+     * See above for error description
     png_get_IHDR(png_ptr, info_ptr, (png_uint_32*)width, (png_uint_32*)height, &bit_depth,
 		 &color_type, &interlace_type, &compression_type, &filter_type);
-
+    */
+    *width = png_get_image_width(png_ptr, info_ptr);
+    *height = png_get_image_height(png_ptr, info_ptr);
+    bit_depth = png_get_bit_depth(png_ptr, info_ptr);
+    color_type = png_get_color_type(png_ptr, info_ptr);
+    interlace_type = png_get_interlace_type(png_ptr, info_ptr);
+    compression_type = png_get_compression_type(png_ptr, info_ptr);
+    
     pixels = (uint8*)malloc(*width * *height * 4);
 
     if (!pixels) {
@@ -443,7 +465,7 @@ int png_to_gdkpixmap(GdkWindow *window, uint8 *data, int len,
     unsigned long width, height;
     png_structp	png_ptr;
     png_infop	info_ptr;
-    int bit_depth, color_type, interlace_type, compression_type, filter_type,
+    int bit_depth, color_type, interlace_type, compression_type,
 	bpp, x,y,has_alpha,i,alpha;
     GdkColor  scolor;
     GdkGC	*gc, *gc_alpha;
@@ -471,10 +493,24 @@ int png_to_gdkpixmap(GdkWindow *window, uint8 *data, int len,
     has_alpha=0;
     png_set_read_fn(png_ptr, NULL, user_read_data);
     png_read_info (png_ptr, info_ptr);
-
+    
+   /*
+    * This seems to bug on at least one system (other than mine)
+    * http://www.metalforge.net/cfmb/viewtopic.php?t=1085
+    *
+    * I think its actually a bug in libpng. This function dies with an 
+    * error based on image width. However I've produced a work around
+    * using the indivial functions. Repeated below.
+    * 
     png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth,
 		 &color_type, &interlace_type, &compression_type, &filter_type);
-
+    */
+    width = png_get_image_width(png_ptr, info_ptr);
+    height = png_get_image_height(png_ptr, info_ptr);
+    bit_depth = png_get_bit_depth(png_ptr, info_ptr);
+    color_type = png_get_color_type(png_ptr, info_ptr);
+    interlace_type = png_get_interlace_type(png_ptr, info_ptr);
+    compression_type = png_get_compression_type(png_ptr, info_ptr);
     if (color_type == PNG_COLOR_TYPE_PALETTE &&
             bit_depth <= 8) {
 
@@ -523,8 +559,24 @@ int png_to_gdkpixmap(GdkWindow *window, uint8 *data, int len,
     /* Update the info the reflect our transformations */
     png_read_update_info(png_ptr, info_ptr);
     /* re-read due to transformations just made */
+    /*
+     * This seems to bug on at least one system (other than mine)
+     * http://www.metalforge.net/cfmb/viewtopic.php?t=1085
+     *
+     * I think its actually a bug in libpng. This function dies with an 
+     * error based on image width. However I've produced a work around
+     * using the indivial functions. Repeated below.
+     *
     png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth,
 		 &color_type, &interlace_type, &compression_type, &filter_type);
+     */
+    width = png_get_image_width(png_ptr, info_ptr);
+    height = png_get_image_height(png_ptr, info_ptr);
+    bit_depth = png_get_bit_depth(png_ptr, info_ptr);
+    color_type = png_get_color_type(png_ptr, info_ptr);
+    interlace_type = png_get_interlace_type(png_ptr, info_ptr);
+    compression_type = png_get_compression_type(png_ptr, info_ptr);
+    
     if (color_type & PNG_COLOR_MASK_ALPHA)
                 bpp = 4;
     else
