@@ -1,5 +1,5 @@
 char *rcsid_x11_xutil_c =
-    "$Id: xutil.c,v 1.16 2004/01/31 20:13:11 tchize Exp $";
+    "$Id: xutil.c,v 1.19 2005/03/27 20:51:25 akirschbaum Exp $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -30,6 +30,7 @@ char *rcsid_x11_xutil_c =
 #include <client.h>
 #include <item.h>
 #include <config.h>
+#include <p_cmd.h>
 
 #ifdef HAVE_LIBXPM
 #include <X11/xpm.h>
@@ -122,11 +123,6 @@ extern char *directions[9];
 #define MAX_KEYCODE 255
 static Key_Entry *keys[256];
 
-/* This holds the name we recieve with the 'face' command so we know what
- * to save it as when we actually get the face.
- */
-char *facetoname[MAXPIXMAPNUM];
-
 /* Can be set when user is moving to new machine type */
 uint8 updatekeycodes=FALSE;
 
@@ -153,16 +149,15 @@ void init_cache_data()
      */
     pixmaps[0]->pixmap=XCreatePixmap(display, win_root, image_size, image_size, 
 	DefaultDepth(display,DefaultScreen(display)));
+    pixmaps[0]->width = 1;
+    pixmaps[0]->height = 1;
     XCopyPlane(display, ptmp, pixmaps[0]->pixmap, gc_game,
 	       0,0,image_size,image_size,0,0,1);
     XFreePixmap(display, ptmp);
 		
-    facetoname[0]=NULL;
-
     /* Initialize all the images to be of the same value. */
     for (i=1; i<MAXPIXMAPNUM; i++)  {
 	pixmaps[i]=pixmaps[0];
-	facetoname[i]=NULL;
     }
 
     init_common_cache_data();
@@ -244,10 +239,16 @@ static void insert_key(KeySym keysym, KeyCode keycode, int flags, char *command)
     Key_Entry *newkey;
     int i, direction=-1;
 
+#if 0
+    /* This is at least a meaningless check on my system that results in
+     * a compile warning (always false result), so may was well comment it
+     * out - MSW 2005-02-09
+     */
     if (keycode>MAX_KEYCODE) {
 	LOG(LOG_WARNING,"x11::insert_key", "keycode that is passed is greater than 255.");
 	keycode=0;	/* hopefully the rest of the data is OK */
     }
+#endif
     if (keys[keycode]==NULL) {
 	keys[keycode]=malloc(sizeof(Key_Entry));
 	keys[keycode]->command=NULL;
@@ -809,7 +810,7 @@ static void show_keys(int allbindings)
 
 
 
-void bind_key(char *params)
+void bind_key(const char *params)
 {
   char buf[MAX_BUF];
 
@@ -922,14 +923,15 @@ void bind_key(char *params)
     return;
   }
 
-    if (strlen(params) >= sizeof(bind_buf)) {
-	params[sizeof(bind_buf) - 1] = '\0';
+  strncpy(bind_buf, params, sizeof(bind_buf)-1);
+  bind_buf[sizeof(bind_buf)-1]=0;
+  if (strlen(params) >= sizeof(bind_buf)) {
     draw_info("Keybinding too long! Truncated:",NDI_RED);
-    draw_info(params,NDI_RED);
-    }
-  sprintf(buf, "Push key to bind '%s'.", params);
+    draw_info(bind_buf,NDI_RED);
+  }
+
+  sprintf(buf, "Push key to bind '%s'.", bind_buf);
   draw_info(buf,NDI_BLACK);
-  strcpy(bind_buf, params);
   bind_keycode=NULL;
   cpl.input_state = Configure_Keys;
   return;
@@ -1067,7 +1069,7 @@ static void unbind_usage()
     draw_info("    -g unbinds a global binding", NDI_BLACK);
 }
 
-void unbind_key(char *params)
+void unbind_key(const char *params)
 {
     int count=0, keyentry, onkey,global=0;
     Key_Entry *key, *tmp;
@@ -1326,7 +1328,7 @@ void set_map_darkness(int x, int y, uint8 darkness)
 	 * let the neighbors know they should update their darkness
 	 * now.
 	 */
-	if (use_config[CONFIG_SDL]) {
+	if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
 	    if (x-1>0) the_map.cells[x-1][y].need_update = 1;
 	    if (y-1>0) the_map.cells[x][y-1].need_update = 1;
 	    if (x+1<use_config[CONFIG_MAPWIDTH]) the_map.cells[x+1][y].need_update = 1;
@@ -1513,3 +1515,9 @@ void reset_map_data()
 	}
     }
 }
+
+
+/* x11 client doesn't do smoothing, so don't need to do anything with this */
+void addsmooth(uint16 face, uint smooth_face)
+{
+}
